Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/AppFramework/Bootstrap/IRegistrationContext.php')
-rw-r--r--lib/public/AppFramework/Bootstrap/IRegistrationContext.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/public/AppFramework/Bootstrap/IRegistrationContext.php b/lib/public/AppFramework/Bootstrap/IRegistrationContext.php
index de391050ec1..3e5aef06e8b 100644
--- a/lib/public/AppFramework/Bootstrap/IRegistrationContext.php
+++ b/lib/public/AppFramework/Bootstrap/IRegistrationContext.php
@@ -255,12 +255,12 @@ interface IRegistrationContext {
/**
* Register an implementation of \OCP\Profile\ILinkAction that
* will handle the implementation of a profile action
*
* @param string $actionClass
* @psalm-param class-string<\OCP\Profile\ILinkAction> $actionClass
* @return void
* @since 23.0.0
*/
- public function registerProfileAction(string $actionClass): void;
+ public function registerProfileLinkAction(string $actionClass): void;
}
@@ -255,12 +255,12 @@ interface IRegistrationContext {
/**
* Register an implementation of \OCP\Profile\ILinkAction that
- * will handle the implementation of a profile action
+ * will handle the implementation of a profile link action
*
* @param string $actionClass